@@ -37,7 +37,7 @@ class LiveData:
         return res
 
     def __str__(self):
-        return self.__dict__
+        return str(self.__dict__)
 
 
 class TouchlineData:
